@@ -168,7 +168,7 @@ class PyAMI:
 
         version = self.version()
         parser = argparse.ArgumentParser(
-            description='Search sections with dictionaries and patterns V0.0.26')
+            description=f'Search sections with dictionaries and patterns V{version}')
         # apply_choices = [self.PDF2TXT, self.PDF2SVG, self.SVG2XML, self.TXT2SENT, self.XML2HTML, self.XML2TXT]
         apply_choices = ConvType.list_values()
         self.logger.debug(f"ch {apply_choices}")
@@ -1110,9 +1110,22 @@ class PyAMI:
             return False
 
     def version(self):
-        version = "0.0.26"
+        """reads setup.py and extracts line of form version='0.0.29'"""
+        import pkg_resources  # part of setuptools
+        version = pkg_resources.require("py4ami")[0].version
         return version
 
+        # version = None
+        # with open(Path(Path(__file__).parent.parent, "setup.py"), "r") as f:
+        #     setup_lines = f.readlines()
+        #     for line in setup_lines:
+        #         match = re.match("\s*version\s*=\s*\'\s*(\d+\.\d+\.\d+)\s*\'\s*,", line)
+        #         if match:
+        #             version = match.group(1)
+        #             break
+        # print(f"VERSION {version}")
+        # return version
+
 
 class ContentStore:
     """holds path-related content
