@@ -1,3 +1,4 @@
+import argparse
 import ast
 import errno
 import logging
@@ -38,7 +39,6 @@ class Util:
         :rtype logger:
 
         """
-        print("pyami: setting logger")
         _logger = logging.getLogger(module)
         _logger.setLevel(logger_level)
         # create path handler
@@ -233,6 +233,23 @@ class Util:
                     (?P<post>.*)
                     """, re.VERBOSE)  # finds a bracket pair in running text, crude
 
+    @classmethod
+    def range_list_contains_int(cls, value, range_list):
+        """Is an in in a list of ranges
+        :param value: int to test
+        :param range_list: list of ranges (or single range)"""
+        if range_list is None:
+            return False
+        # might be a single range
+        if type(range_list) is range:
+            return value in range_list
+        for rangex in range_list:
+            if value in rangex:
+                return True
+        return False
+
+
+
 
 class GithubDownloader:
     """Note: Github uses the old 'master' name but we have changed it to 'main'"""
@@ -322,17 +339,17 @@ class AbstractArgs(ABC):
         self.ref_counter = Counter()
         self.arg_dict = self.create_default_arg_dict()
 
-    @property
-    @abstractmethod
-    def module_stem(self):
-        pass
-
-
-    def create_arg_dict(self):
-        print(f"PARSED_ARGS {self.parsed_args}")
+    def create_arg_dict(self, args=None):
+        if args:
+            self.parsed_args = args
+        # print(f"PARSED_ARGS {type(self.parsed_args)} {self.parsed_args}")
         if not self.parsed_args:
             return None
-        arg_vars = vars(self.parsed_args)
+        try:
+            arg_vars = vars(self.parsed_args)
+        except TypeError:
+            # print(f" type args {type(self.parsed_args)} {self.parsed_args}")
+            arg_vars = self.parsed_args
         self.arg_dict = dict()
         for item in arg_vars.items():
             key = item[0]
@@ -343,6 +360,7 @@ class AbstractArgs(ABC):
             else:
                 self.arg_dict[key] = item[1]
 
+        print(f"ARG_DICT {self.arg_dict}")
         return self.arg_dict
 
     def parse_and_process(self):
@@ -359,19 +377,28 @@ class AbstractArgs(ABC):
         print(f"module_stem {self.module_stem}\n sys.argv {sys.argv}")
         while len(sys.argv) > 0 and self.module_stem not in str(sys.argv[0]):
             sys.argv = sys.argv[1:]
-        self.create_arg_parser()
+        self.add_arguments()
         # print(f"argv {sys.argv}")
         if len(sys.argv) == 1:  # no args, print help
             self.parser.print_help()
         else:
             argv_ = sys.argv[1:]
-            # print(f"argv: {argv_}")
-            self.parsed_args = self.parser.parse_args(argv_)
-            self.arg_dict = self.create_arg_dict()
-            self.process_args()
+            print(f"argv: {argv_}")
+            self.parse_and_process1(argv_)
 
-    @abstractmethod
-    def create_arg_parser(self):
+    def parse_and_process1(self, argv_):
+        self.parsed_args = argv_ if self.parser is None else self.parser.parse_args(argv_)
+        self.arg_dict = self.create_arg_dict()
+        print(f"ARG_DICT {self.arg_dict}")
+        self.process_args()
+
+    @property
+    # @abstractmethod  # I don't know why this doesn't work
+    def subparser_name(self):
+        pass
+
+    # @abstractmethod
+    def add_argumants(self):
         pass
 
     @abstractmethod
@@ -382,6 +409,86 @@ class AbstractArgs(ABC):
     def create_default_arg_dict(self):
         pass
 
+    @property
+    def subparser_arg(self):
+        """extracts suparser arg (e.g. 'DICT',(base) pm286macbook:pyami pm286$ python -m py4ami.pyamix DICT --dict /Users/pm286/projects/semanticClimate/ipcc//ar6/wg3/Chapter02/dict/emissions.xml --valid
+===========LOGGING 30 .. 10
+WARNING:pyami:
+============== running pyami main ===============
+['DICT', '--dict', '/Users/pm286/projects/semanticClimate/ipcc//ar6/wg3/Chapter02/dict/emissions.xml', '--valid']
+ COMMAND: DICT
+reading /Users/pm286/projects/semanticClimate/ipcc//ar6/wg3/Chapter02/dict/emissions.xml as dictionary
+dictionary.entries 33
+entry_by_term 33
+title emissions
+VALIDATING <py4ami.ami_dict.AmiDictionary object at 0x7fcfb34981f0>
+forbidden child synonym ; allowed = {'entry', 'desc'}
+forbidden child synonym ; allowed = {'entry', 'desc'}
+forbidden child synonym ; allowed = {'entry', 'desc'}
+forbidden child synonym ; allowed = {'entry', 'desc'}
+forbidden child synonym ; allowed = {'entry', 'desc'}
+(base) pm286macbook:pyami pm286$
+ """
+        stem = self.module_stem.replace("ami_", "")
+        return stem.upper()
+
+
+    def make_run_func(self):
+        """probably obsolete"""
+        func_name = self.module_stem.replace("ami_", "run_")
+        print(f"run_func_name {func_name}")
+        return func_name
+
+    def make_sub_parser(self, subparsers):
+        """make subparser from subparsers
+        requires self.subparser_arg (probably should be argument
+        ALSO adds arguments through `self.add_arguments`
+        :param subparsers: subparser generator
+        :return: new subparser"""
+        self.parser = subparsers.add_parser(self.subparser_arg)
+        subparser_arg = self.parser.prog.split()[1]
+        self.add_arguments()
+        return self.parser
+
+
+class ArgParseBuilder:
+
+    ARG_LIST = "arg_list"
+    DESCRIPTION = "description"
+
+    def __init__(self):
+        self.parser = None
+
+    def create_arg_parse(self, arg_dict=None, arg_dict_file=None):
+        # arg_dict_file takes precedence
+        if arg_dict_file and arg_dict_file.exists():
+            with open(arg_dict_file, 'r') as f:
+                data = f.read()
+                arg_dict = json.loads(data)
+                print(f"arg_dict {arg_dict}")
+
+        if arg_dict is not None:
+            desc = f'{arg_dict.get(self.DESCRIPTION)}'
+            print(f"\ndesc: '{desc}'")
+            self.parser = argparse.ArgumentParser(description=desc)
+            arg_list = arg_dict.get(self.ARG_LIST)
+            if arg_list is None:
+                raise ValueError(f"must give arg_list to ArgParseBuilder")
+            for arg_dict in arg_list:
+                if not type(arg_dict) is dict:
+                    raise ValueError(f"arg_list_dict {arg_dict} is not a dict")
+                args = arg_dict.keys()
+                for arg in args:
+                    print(f"\n{arg}:")
+                    param_dict = arg_dict.get(arg)
+                    self.process_params(param_dict)
+                # self.parser.add_argument(f"--{ProjectArgs.PROJECT}", type=str, nargs=1, help="project directory")
+
+    """https://stackoverflow.com/questions/28348117/using-argparse-and-json-together"""
+    def process_params(self, param_dict):
+        for param, param_val in param_dict.items():
+            print(f"  {param}='{param_val}'")
+
 
 class AmiLogger:
     """wrapper for logger to limit or condense voluminous output
